import org.trinitydesktop.qt.*;

public class LCDRange extends TQWidget {
	private TQSlider slider;
	private TQLabel label;
	
	public LCDRange(TQWidget parent, String name) {
		super(parent, name);
		init();
	}
	
	public LCDRange(String s, TQWidget parent, String name) {
		super(parent, name);
		init();
		setText(s);
	}

	private void init() {
		TQLCDNumber lcd = new TQLCDNumber(2, this, "lcd");
		slider = new TQSlider(Horizontal, this, "slider");
		slider.setRange(0, 99);
		slider.setValue(0);

		label = new TQLabel(" ", this, "label", 0);
		label.setAlignment(AlignCenter);
		
		connect(slider, TQ_SIGNAL("valueChanged(int)"),
						lcd, TQ_SLOT("display(int)"));
		connect(slider, TQ_SIGNAL("valueChanged(int)"),
						TQ_SIGNAL("valueChanged(int)"));

		setFocusProxy(slider);

		TQVBoxLayout l = new TQVBoxLayout(this);
		l.addWidget(lcd, 1);
		l.addWidget(slider);
		l.addWidget(label);
	}

	public int value() {
		return slider.value();
	}

	public void setValue(int value) {
		slider.setValue(value);
	}

	public void setRange(int minVal, int maxVal) {
		if (minVal < 0 || maxVal > 99 || minVal > maxVal) {
			tqWarning("LCDRange::setRange("+minVal+","+maxVal+")\n"+
							 "\tRange must be 0..99\n"+
							 "\tand minVal must not be greater than maxVal");
			return;
		}
		slider.setRange(minVal, maxVal);
	}

	public void setText(String s) {
		label.setText(s);
	}
}
